/*
 *  gettimeofday()
 *
 *  The prototype specified in the XOpen/POSIX 1.3 standards, and the one 
 *  used on modern (ie 4.4BSD spec) BSDs is:
 *      int gettimeofday(struct timeval *, ...);
 *      The second argument, if specified, is ignored.
 *
 *  The 4.2BSD (Tahoe) prototype, ie the prototype originally used in
 *  the very first incarnation of gettimeofday(), is:
 *      int gettimeofday (struct timeval *tv, struct timezone *tz);
 *
 *  To determine which prototype to use, compile this module with c++.
 *  If it barfs on 'struct timezone' (because 'timezone' is already 
 *  prototyped as something else, usually as a 'long'), then you MUST 
 *  use the modern XOpen/POSIX 1.3 and 4.4BSD prototype.
 *  
 *  G. Vanem <giva@bgnett.no>
 *
 *  10.aug 1996 - Created
 *
*/
#if !defined(__DJGPP__) /* djgpp already has gettimeofday */

#include <sys/time.h>   /* timeval, gettimeofday() */
#include <sys/timeb.h>  /* ftimeb() */

#if defined(__WATCOMC__)
#undef FORCE_TAHOE_PROTOTYPE
#elif defined(__TURBOC__) && (__TURBOC__ <= 0x410) /* TCC/BCC <= 3.1 */
#undef FORCE_TAHOE_PROTOTYPE
#elif defined(_MSC_VER) && (_MSC_VER <= 600)
#undef FORCE_TAHOE_PROTOTYPE
#else
#define FORCE_TAHOE_PROTOTYPE
#endif

#if defined(FORCE_TAHOE_PROTOTYPE)
int gettimeofday(struct timeval *tv, struct timezone *tz)
#else
int gettimeofday(struct timeval *tv, ...)
#endif
{
  struct timeb tb;
  ftime( &tb );
  if (tv)
  {
    tv->tv_sec = tb.time;
    tv->tv_usec = 1000ul * ((unsigned long)tb.millitm);
  } 
  #ifdef FORCE_TAHOE_PROTOTYPE
  if (tz)
  {
    tz->tz_minuteswest = tb.timezone;
    tz->tz_dsttime = (tb.dstflag ? -1 /*unknown*/ : 0 /*DST_NONE*/);
  }
  #endif
  return 0;
}

#endif /* !defined(__DJGPP__) */

